@@ -40,7 +40,7 @@ def ntuple(name, fields):
 
 
 Dive = ntuple('Dive', 'datetime depth duration temp profile equipment')
-Sample = ntuple('Sample', 'depth time temp setpoint' \
+Sample = ntuple('Sample', 'depth time temp setpoint setpointby' \
         ' deco_time deco_depth alarm gas')
 Gas = ntuple('Gas', 'id name o2 he')
 BinaryData = ntuple('BinaryData', 'datetime data')
