@@ -34,7 +34,7 @@ import kenozooid.data as kd
 
 UDDF_PROFILE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
   <generator>
     <name>kenozooid</name>
     <version>0.1.0</version>
@@ -65,11 +65,6 @@ UDDF_PROFILE = b"""\
         <informationbeforedive>
             <datetime>2009-09-19T13:10:23</datetime>
         </informationbeforedive>
-        <informationafterdive>
-            <diveduration>20</diveduration>
-            <greatestdepth>30.2</greatestdepth>
-            <lowesttemperature>251.4</lowesttemperature>
-        </informationafterdive>
         <samples>
           <waypoint>
             <depth>1.48</depth>
@@ -86,16 +81,16 @@ UDDF_PROFILE = b"""\
             <divetime>20</divetime>
           </waypoint>
         </samples>
+        <informationafterdive>
+            <diveduration>20</diveduration>
+            <greatestdepth>30.2</greatestdepth>
+            <lowesttemperature>251.4</lowesttemperature>
+        </informationafterdive>
       </dive>
       <dive id='d02'>
         <informationbeforedive>
             <datetime>2010-10-30T13:24:43</datetime>
         </informationbeforedive>
-        <informationafterdive>
-            <diveduration>30</diveduration>
-            <greatestdepth>32.2</greatestdepth>
-            <lowesttemperature>250.4</lowesttemperature>
-        </informationafterdive>
         <samples>
           <waypoint>
             <depth>2.61</depth>
@@ -116,6 +111,11 @@ UDDF_PROFILE = b"""\
             <temperature>297.26</temperature>
           </waypoint>
         </samples>
+        <informationafterdive>
+            <diveduration>30</diveduration>
+            <greatestdepth>32.2</greatestdepth>
+            <lowesttemperature>250.4</lowesttemperature>
+        </informationafterdive>
       </dive>
     </repetitiongroup>
   </profiledata>
@@ -124,7 +124,7 @@ UDDF_PROFILE = b"""\
 
 UDDF_DUMP = b"""\
 <?xml version='1.0' encoding='utf-8'?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
   <generator>
     <name>kenozooid</name>
     <version>0.1.0</version>
@@ -162,7 +162,7 @@ UDDF_DUMP = b"""\
 
 UDDF_BUDDY = b"""\
 <?xml version='1.0' encoding='utf-8'?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
 <diver>
     <owner>
         <personal>
@@ -192,7 +192,7 @@ UDDF_BUDDY = b"""\
 
 UDDF_SITE = b"""\
 <?xml version='1.0' encoding='utf-8'?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
 <divesite>
     <site id='markgraf'><name>SMS Markgraf</name><geography><location>Scapa Flow</location></geography></site>
     <site id='konig'><name>SMS Konig</name><geography><location>Scapa Flow</location></geography></site>
@@ -345,6 +345,22 @@ class FindDataTestCase(unittest.TestCase):
         self._qt(UDDF_SITE, ku.XP_FIND_SITE, 'markgraf', site='Scapa Flow')
 
 
+    def test_version(self):
+        """
+        Test getting UDDF version
+        """
+        s1 = b"""\
+<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+</uddf>
+"""
+        s2 = b"""\
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
+</uddf>
+"""
+        self.assertEquals((3, 0), ku.get_version(BytesIO(s1)))
+        self.assertEquals((3, 1), ku.get_version(BytesIO(s2)))
+
+
 
 class CreateDataTestCase(unittest.TestCase):
     """
@@ -357,7 +373,7 @@ class CreateDataTestCase(unittest.TestCase):
         now = datetime.now()
 
         doc = ku.create(datetime=now)
-        self.assertEquals('3.0.0', doc.get('version'))
+        self.assertEquals('3.1.0', doc.get('version'))
 
         q = '//uddf:generator/uddf:datetime/text()'
         dt = ku.xp_first(doc, q)
@@ -377,7 +393,7 @@ class CreateDataTestCase(unittest.TestCase):
 
         preamble = b"""\
 <?xml version='1.0' encoding='utf-8'?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">\
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">\
 """
         self.assertTrue(s.startswith(preamble), s)
 
@@ -697,6 +713,10 @@ class CreateDataTestCase(unittest.TestCase):
         r = ku.xp_first(doc, '//uddf:owner//uddf:divecomputer/uddf:model/text()')
         self.assertEquals(r, 'Test 1', sd)
 
+        # name is the same as model
+        r = ku.xp_first(doc, '//uddf:owner//uddf:divecomputer/uddf:name/text()')
+        self.assertEquals(r, 'Test 1', sd)
+
 
     def test_create_dive_samples(self):
         """
@@ -724,10 +744,12 @@ class CreateDataTestCase(unittest.TestCase):
         """
         Test UDDF dive profile sample creation with setpoint
         """
-        s = kd.Sample(depth=3.1, time=19, temp=20, setpoint=1.17),
+        s = kd.Sample(depth=3.1, time=19, temp=20, setpoint=1.17,
+                setpointby='user'),
         samples = ku.create_dive_samples(s)
         n, sd = xml2et(xml.dive(samples))
         self.assertEquals('1.17', ku.xp_first(n, '//setpo2/text()'), sd)
+        self.assertEquals('user', ku.xp_first(n, '//setpo2/@setby'), sd)
         
 
     def test_dump_data_encode(self):
@@ -894,7 +916,7 @@ class PostprocessingTestCase(unittest.TestCase):
         Test UDDF reordering
         """
         doc = et.parse(BytesIO(b"""
-<uddf xmlns="http://www.streit.cc/uddf/3.0/">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/">
 <generator>
     <name>kenozooid</name>
 </generator>
@@ -1018,7 +1040,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a2/>
         <a2/>
@@ -1030,7 +1052,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1041,7 +1063,7 @@ class NodeCopyTestCase(unittest.TestCase):
         c = ku.xp_first(t, '//uddf:c')
 
         r = ku.copy(a, c)
-        self.assertEquals('{http://www.streit.cc/uddf/3.0/}a1', r.tag)
+        self.assertEquals('{http://www.streit.cc/uddf/3.1/}a1', r.tag)
 
         n = ku.xp_first(t, '//uddf:a1')
         self.assertTrue(n is not None)
@@ -1054,7 +1076,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a2 id = 'id-a1'/>
         <a2 id = 'id-a2' ref = 'id-a1'/>
@@ -1066,7 +1088,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1089,7 +1111,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a2 id = 'id-a1'/>
         <a2 id = 'id-a2' ref = 'id-b2'/>
@@ -1101,7 +1123,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
     <b1>
         <b2 id = 'id-b2'/>
@@ -1131,7 +1153,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a2 id = 'id-a1'/>
         <a2 id = 'id-a2' ref = 'id-b1'/>
@@ -1143,7 +1165,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1167,7 +1189,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a2 id = 'id-a21'/>
         <a2 id = 'id-a22' ref = 'id-b1'/>
@@ -1181,7 +1203,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1207,7 +1229,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a3 id = 'id-a3'>
             <a5 id = 'id-a5'>
@@ -1224,7 +1246,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1255,7 +1277,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1>
         <a3 id = 'id-a3'>
             <a5 id = 'id-a5' ref = 'id-b2'>
@@ -1272,7 +1294,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
@@ -1303,7 +1325,7 @@ class NodeCopyTestCase(unittest.TestCase):
         """
         SOURCE = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <a1 ref = 'id-b1'>
         <a2 ref = 'id-b2'/>
     </a1>
@@ -1314,7 +1336,7 @@ class NodeCopyTestCase(unittest.TestCase):
 """
         TARGET = b"""\
 <?xml version="1.0" encoding="utf-8"?>
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
     <c/>
 </uddf>
 """
