@@ -66,7 +66,7 @@ log = logging.getLogger('kenozooid.uddf')
 #
 # Default UDDF namespace mapping.
 #
-_NSMAP = {'uddf': 'http://www.streit.cc/uddf/3.0/'}
+_NSMAP = {'uddf': 'http://www.streit.cc/uddf/3.1/'}
 
 # Node id formatter
 FORMAT_ID = 'id-{}'
@@ -96,6 +96,7 @@ XP_DEFAULT_PROFILE_DATA =  (
     XPath('uddf:divetime/text()'),
     XPath('uddf:temperature/text()'),
     XPath('uddf:setpo2/text()'),
+    XPath('uddf:setpo2/@setby'),
     XPath('uddf:decostop/@duration'),
     XPath('uddf:decostop/@decodepth'),
     XPath('uddf:alarm/text()'),
@@ -368,11 +369,11 @@ def dive_profile(node, fields=None, queries=None, parsers=None):
         find_data
     """
     if fields is None:
-        fields = ('depth', 'time', 'temp', 'setpoint',
+        fields = ('depth', 'time', 'temp', 'setpoint', 'setpointby',
                 'deco_time', 'deco_depth', 'alarm', 'gas')
         queries = XP_DEFAULT_PROFILE_DATA
         gases = dict(((gas.id, gas) for gas in gas_data(node)))
-        parsers = (float, ) * 6 + (str, gases.get)
+        parsers = (float, ) * 4 + (str, float, float, str, gases.get)
 
     return find_data('Sample', node, fields, queries, parsers,
             nquery=XP_WAYPOINT)
@@ -606,7 +607,7 @@ DEFAULT_FMT_DIVE_PROFILE = {
 # basic data for an UDDF file
 # fixme: obsolete
 UDDF_BASIC = """\
-<uddf xmlns="http://www.streit.cc/uddf/3.0/" version="3.0.0">
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">
 <generator>
     <name>kenozooid</name>
     <manufacturer id='kenozooid'>
@@ -671,7 +672,7 @@ def save(doc, f, validate=True):
 
     if validate:
         log.debug('validating uddf file')
-        fs = pkg_resources.resource_stream('kenozooid', 'uddf_3.0.1.xsd')
+        fs = pkg_resources.resource_stream('kenozooid', 'uddf/uddf_3.1.0.xsd')
         if hasattr(fs, 'name'):
             log.debug('uddf xsd found: {}'.format(fs.name))
         schema = et.XMLSchema(et.parse(fs))
@@ -954,7 +955,7 @@ def create_uddf(datetime=datetime.now(), equipment=None, gases=None, dives=None,
             if dives else None,
 
         xmlns=_NSMAP['uddf'],
-        version='3.0.0',
+        version='3.1.0',
     )
     return doc
 
@@ -1020,7 +1021,8 @@ def create_dive_samples(samples):
                 ),
             xml.depth(FMT_F(s.depth)),
             xml.divetime(FMT_I(s.time)),
-            None if s.setpoint is None else xml.setpo2(FMT_F2(s.setpoint)),
+            None if s.setpoint is None else xml.setpo2(FMT_F2(s.setpoint),
+                setby=s.setpointby),
             None if s.gas is None else xml.switchmix(ref=str(s.gas.id)),
             None if s.temp is None else xml.temperature(FMT_F(s.temp)),
         )
@@ -1052,7 +1054,7 @@ def create_dc_data(dc_id, model):
      model
         Dive computer model.
     """
-    yield xml.divecomputer(xml.model(model), id=dc_id)
+    yield xml.divecomputer(xml.name(model), xml.model(model), id=dc_id)
 
 
 def create_dump_data(dc_id, datetime, data):
@@ -1092,7 +1094,7 @@ def save_uddf(doc, fout, validate=True):
 
     if validate:
         log.debug('validating uddf file')
-        fs = pkg_resources.resource_stream('kenozooid', 'uddf_3.0.1.xsd')
+        fs = pkg_resources.resource_stream('kenozooid', 'uddf/uddf_3.1.0.xsd')
         if hasattr(fs, 'name'):
             log.debug('uddf xsd found: {}'.format(fs.name))
         schema = et.XMLSchema(et.parse(fs))
@@ -1267,4 +1269,20 @@ def xml_file_copy(f):
         yield RawString(l)
 
 
+def get_version(f):
+    """
+    Get major version of UDDF file.
+
+    Tuple (major, minor) is returned, i.e. (3, 0), (3, 1), etc.
+
+    :Parameters:
+     f
+        File to check.
+    """
+    n = et.parse(f).getroot()
+    v1, v2, *_ = n.get('version').split('.')
+    f.seek(0, 0)
+    return int(v1), int(v2)
+
+
 # vim: sw=4:et:ai
